<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2019 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

namespace Akeeba\TicketSystem\Admin\Dispatcher;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Blade;
use Akeeba\TicketSystem\Admin\Helper\ComponentParams;
use FOF30\Container\Container;
use FOF30\Dispatcher\Mixin\ViewAliases;

class Dispatcher extends \FOF30\Dispatcher\Dispatcher
{
	/** @var   string  The name of the default view, in case none is specified */
	public $defaultView = 'ControlPanel';

	use ViewAliases {
		onBeforeDispatch as onBeforeDispatchViewAliases;
	}

	public function __construct(Container $container, array $config)
	{
		parent::__construct($container, $config);

		$this->viewNameAliases = [
			'cpanel'             => 'ControlPanel',
		];

		// Add our custom Blade templates
		Blade::extend($container);
	}

	public function onBeforeDispatch()
	{
		$this->onBeforeDispatchViewAliases();

		if (!@include_once(JPATH_ADMINISTRATOR . '/components/com_ats/version.php'))
		{
			define('ATS_PRO', '0');
			define('ATS_VERSION', 'dev');
			define('ATS_DATE', date('Y-m-d'));
		}

		// Renderer options (0=none, 1=frontend, 2=backend, 3=both)
		$useFEF   = $this->container->params->get('load_fef', 3);
		$fefReset = $this->container->params->get('fef_reset', 3);

		if (!in_array($useFEF, [2,3]))
		{
			$this->container->rendererClass = '\\FOF30\\Render\\Joomla3';
		}

		$this->container->renderer->setOption('load_fef', in_array($useFEF, [2,3]));
		$this->container->renderer->setOption('fef_reset', in_array($fefReset, [2,3]));

		// Render submenus as drop-down navigation bars powered by Bootstrap
		$this->container->renderer->setOption('linkbar_style', 'classic');

		// Load common CSS and JavaScript
		\JHtml::_('jquery.framework');

		// Make sure akeeba.jQuery is always defined
		$this->container->template->addJS('media://com_ats/js/namespaced.js', false, false, $this->container->mediaVersion);

		$this->container->template->addCSS('media://com_ats/css/backend.css', $this->container->mediaVersion);

		// If Joomla is using SEF URLs, but URL rewrite is OFF (so we have index.php/foobar/test urls),
		// I have to use absolute URLs, otherwise all the requests are performed vs the current page, not the site root
		if($this->input->getCmd('format', 'html') == 'html')
		{
			$root = \JUri::root().'administrator/';
			$js = <<<JS
var ATS_ROOT_URL = "$root";

JS;
			$this->container->template->addJSInline($js);
		}
	}
}
